==> moodle-1.4.3-pgsql.tgz: moodle/lang/ja_utf8/wiki.php <==
<?php // $Id$ 
      // wiki.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004112900)


$string['action'] = '-- アクション --';
$string['administration'] = '管理';
$string['allowremovepages'] = '「ページの削除」を許可';
$string['allowrevertchanges'] = '「変更の大量取消し」を許可';
$string['allowsetpage'] = '「ページフラグ設定」を許可';
$string['allowstrippages'] = '「ページストリップ」を許可';
$string['attachments'] = '添付ファイル';
$string['author'] = '著者';
$string['authorfieldpattern'] = '著者フィールドパターン';
$string['authorfieldpatternerror'] = '著者を入力してください。';
$string['backlinks'] = '参照リンク';
$string['binimgtoolarge'] = 'イメージファイルが大き過ぎます!';
$string['binnoimg'] = '許可されていないファイルタイプです!';
$string['browse'] = '閲覧';
$string['canceledit'] = 'キャンセル';
$string['cannotchangepage'] = 'このページは更新できません。';
$string['changes'] = '$a 変更';
$string['changesfield'] = '最後の更新から何時間前';
$string['changesfielderror'] = '正しい時間を入力してください。';
$string['checklinks'] = 'リンクをチェックする';
$string['checklinkscheck'] = '本当にこのページのリンクをチェックしますか:';
$string['checklinksnotice'] = 'しばらくお待ちください。';
$string['chooseadministration'] = '-- 管理 --';
$string['chooseafile'] = '初期ページの選択/アップロード';
$string['choosewikilinks'] = '-- Wiki リンクの選択 --';
$string['comment'] = 'コメント';
$string['contentsize'] = 'コンテンツサイズ';
$string['created'] = '作成日時';
$string['deletemewikiword'] = '削除';
$string['deletemewikiwordfound'] = '$a 件見つかりました。';
$string['deletepage'] = 'ページの削除';
$string['deleteversions'] = '最新バージョンの削除数';
$string['deleteversionserror'] = '正しいバージョンのカウントを入力してください。';
$string['diff'] = 'Diff';
$string['differences'] = '$a->pagename におけるバージョン $a->new_ver と $a->old_ver の違い。';
$string['disablecamel'] = 'キャメルケースリンクを無効にする';
$string['disabledpage'] = 'このページは現在利用できません。';
$string['doesnotexist'] = 'このページは存在していません。作成したい場合は、編集ボタンをクリックしてください。';
$string['downloadaszip'] = 'ダウンロード可能なzip書庫';
$string['downloadtimes'] = 'ダウンロード回数: $a 回';
$string['dwnlnofiles'] = 'アップロードされたファイルはありません。';
$string['dwnlsection'] = 'ダウンロードセクション';
$string['editform1'] = 'フォーマットのことを心配せずに書き込んでください。フォーマットは後から変更することができます。';
$string['editform2'] = '慎重に書き込んでください。全ての編集は記録されます。';
$string['editthispage'] = '編集';
$string['emptypage'] = '空のページ';
$string['errorbinandtxt'] = 'フラグエラー: ページタイプはBINまたはTXTです。';
$string['errorhtml'] = 'ページタイプHTML';
$string['errornotype'] = 'フラグエラー: BIN、TXTのどちらでもありません。';
$string['errororreason'] = '備考';
$string['errorroandwr'] = 'フラグエラー: ページに書き込み権と読み取り専用の設定がなされています。';
$string['errorsize'] = 'ページサイズが64Kを超えています';
$string['errversionsave'] = '申し訳ございません、このページを編集している間に他の人が更新したバージョンを保存しました。前のページに戻って、内容をクリップボードにコピーしてください。ページのリロード後、コピーした内容をページに挿入してください。';
$string['ewikiacceptbinary'] = 'バイナリファイルを許可する';
$string['ewikiprinttitle'] = 'wiki名を全てのページに表示する。';
$string['export'] = 'エクスポート';
$string['exportformats'] = 'エクスポートフォーマット';
$string['exportsuccessful'] = 'エクスポートが完了しました。';
$string['exportto'] = 'エクスポート先';
$string['fetchback'] = 'フェッチバック';
$string['file'] = 'ファイル';
$string['filedownload'] = 'ファイルダウンロード';
$string['fileisoftype'] = 'ファイルタイプ';
$string['filtername'] = 'Wikiページ自動リンク';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'フラグ';
$string['flagsset'] = 'フラグが変更されました';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['forbidden'] = 'このページにアクセスする権限がありません。';
$string['groups'] = 'グループ';
$string['hits'] = '$a ヒット';
$string['howtooperate'] = '操作方法';
$string['howtowiki'] = 'wikiの使い方';
$string['html'] = 'HTMLフォーマット';
$string['htmlmode'] = 'HTMLモード';
$string['htmlonly'] = 'HTMLのみ';
$string['index'] = 'index';
$string['infoaboutpage'] = 'ページの情報';
$string['initialcontent'] = '初期ページの選択';
$string['invalidroot'] = '現在のルートページにアクセスする権限が無いため、サイトマップは作成できません。';
$string['lastchanged'] = '最終更新: $a';
$string['lastmodified'] = '最終更新';
$string['linkdead'] = 'DEAD';
$string['linkok'] = 'OK';
$string['linkschecked'] = 'チェック済みリンク';
$string['listall'] = '全てを表示';
$string['listcandidates'] = '候補一覧';
$string['meta'] = 'メタデータ';
$string['moduledirectory'] = 'モジュールディクショナリ';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wiki';
$string['mostoftenchangedpages'] = '最多変更ページ';
$string['mostvisitedpages'] = '最多閲覧ページ';
$string['newestpages'] = '最新ページ';
$string['noadministrationaction'] = '管理者権限がありません。';
$string['nocandidatestoremove'] = '削除候補ページがありません、ページ全部を表示するには「 $a 」を選択してください。';
$string['nochangestorevert'] = '前の状態に戻す変更はありません。';
$string['nohtml'] = 'HTML無し';
$string['nolinksfound'] = 'ページにリンクは見つかりませんでした。';
$string['notadministratewiki'] = 'このwikiの管理を許可されていません!';
$string['nothingtostrip'] = '1つのバージョン以外にページがありません。';
$string['nowikicreated'] = 'このwikiにはエントリがありません。';
$string['offline'] = 'オフライン';
$string['optional'] = 'オプション';
$string['orphanedpage'] = '迷子ページ';
$string['orphanedpages'] = '迷子ページ';
$string['otherwikis'] = '他のWiki';
$string['ownerunknown'] = '不明';
$string['pageactions'] = 'ページアクション';
$string['pageindex'] = 'ページインデックス';
$string['pageinfo'] = 'ページ情報';
$string['pagename'] = 'ページ名';
$string['pagenamechoice'] = '- または -';
$string['pageslinkingto'] = 'このページにリンクしているページ';
$string['pagesremoved'] = 'ページが削除されました。';
$string['pagesreverted'] = '変更が元に戻されました';
$string['pagesstripped'] = 'ページがストリップされました。';
$string['plaintext'] = 'プレインテキスト';
$string['preview'] = 'プレビュー';
$string['readonly'] = '読み取り専用ページ';
$string['refs'] = 'リファレンス';
$string['removepagecheck'] = '本当にこれらのページを削除してもよろしいですか?';
$string['removepages'] = 'ページの削除';
$string['removeselectedpages'] = '選択したページを削除';
$string['revertchanges'] = '変更を元に戻す';
$string['revertpages'] = '変更の大量取消し';
$string['revertpagescheck'] = '本当に次の変更を元に戻してもよろしいですか:';
$string['safehtml'] = 'セーフHTML';
$string['save'] = '保存';
$string['searchwiki'] = 'Wikiの検索';
$string['setpageflags'] = 'ページフラグの設定';
$string['sitemap'] = 'サイトマップ';
$string['smfor'] = 'サイトマップ:';
$string['status'] = 'ステータス';
$string['strippagecheck'] = '本当に、これらのページから古いバージョンをストリップしてもよろしいですか:';
$string['strippages'] = 'ページのストリップ';
$string['studentadminoptions'] = '学生管理オプション';
$string['submit'] = '実行';
$string['tabattachments'] = '添付ファイル';
$string['tabedit'] = '編集';
$string['tabinfo'] = '情報';
$string['tablinks'] = 'リンク';
$string['tabview'] = '表示';
$string['thanksforcontribution'] = 'ご協力ありがとうございます。';
$string['thispageisntlinkedfromanywhereelse'] = 'このページはどこからもリンクされていません。';
$string['updatedpages'] = '更新ページ';
$string['uplerror'] = '申し訳ございません、ファイルのアップロード中にエラーが発生しました。';
$string['uplinsect'] = 'アップロード先';
$string['uplnewnam'] = '別名で保存する';
$string['upload0'] = '任意のバイナリファイルをwikiにアップロードする場合は、このフォームを使用してください。';
$string['uploadedon'] = 'アップロード先';
$string['uploadpicturebutton'] = 'アップロード';
$string['uplok'] = 'ファイルが正常にアップロードされました。';
$string['version'] = 'バージョン';
$string['versionrangetoobig'] = '全てのバージョンのページを削除することはできません!最新のバージョンを残してください。';
$string['versions'] = 'バージョン';
$string['versionstodelete'] = '削除するバージョン';
$string['viewpage'] = 'ページの表示';
$string['viewsmfor'] = 'サイトマップを表示';
$string['wantedpages'] = '執筆が望まれているページ';
$string['wikidefaultpagename'] = 'Wikiインデックス';
$string['wikiexport'] = 'ページのエクスポート';
$string['wikiexportcomment'] = 'エクスポートに関する設定を行ってください。';
$string['wikilinkoptions'] = 'Wiki自動リンクオプション';
$string['wikilinks'] = 'Wikiリンク';
$string['wikiname'] = 'ページ名';
$string['wikistartederror'] = '既にエントリが存在します - 変更できません。';
$string['wikitype'] = 'タイプ';
$string['wikiusage'] = 'Wiki使用法';
$string['withbinaries'] = 'バイナリコンテンツを含む';
$string['withvirtualpages'] = 'Wikiリンクを含む';
$string['wrongversionrange'] = '$a は正しい範囲にありません!';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/ja_utf8/wiki.php <==
<?PHP // $Id$ 
      // wiki.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005041101)


$string['action'] = '-- アクション --';
$string['administration'] = '管理';
$string['allowremovepages'] = '「ページの削除」を許可';
$string['allowrevertchanges'] = '「変更の大量取消し」を許可';
$string['allowsetpage'] = '「ページフラグ設定」を許可';
$string['allowstrippages'] = '「ページストリップ」を許可';
$string['attachments'] = '添付ファイル';
$string['author'] = '著者';
$string['authorfieldpattern'] = '著者フィールドパターン';
$string['authorfieldpatternerror'] = '著者を入力してください。';
$string['backlinks'] = '参照リンク';
$string['binimgtoolarge'] = 'イメージファイルが大き過ぎます!';
$string['binnoimg'] = '許可されていないファイルタイプです!';
$string['browse'] = '表示';
$string['canceledit'] = 'キャンセル';
$string['cannotchangepage'] = 'このページは更新できません。';
$string['changes'] = '$a 変更';
$string['changesfield'] = '最後の更新から何時間以内';
$string['changesfielderror'] = '正しい時間を入力してください。';
$string['checklinks'] = 'リンクのチェック';
$string['checklinkscheck'] = '本当にこのページのリンクをチェックしますか:';
$string['checklinksnotice'] = 'しばらくお待ちください。';
$string['chooseadministration'] = '-- 管理 --';
$string['chooseafile'] = '初期ページの選択/アップロード';
$string['choosewikilinks'] = '-- Wiki リンクの選択 --';
$string['comment'] = 'コメント';
$string['contentsize'] = 'コンテンツサイズ';
$string['created'] = '作成日時';
$string['deletemewikiword'] = '削除';
$string['deletemewikiwordfound'] = '$a 件見つかりました。';
$string['deletepage'] = 'ページの削除';
$string['deleteversions'] = '最新バージョンの削除数';
$string['deleteversionserror'] = '正しいバージョンのカウントを入力してください。';
$string['diff'] = 'Diff';
$string['differences'] = '$a->pagename におけるバージョン $a->new_ver と $a->old_ver の違い。';
$string['disablecamel'] = 'キャメルケースリンクを無効にする';
$string['disabledpage'] = 'このページは現在利用できません。';
$string['doesnotexist'] = 'このページは存在していません。作成したい場合は、編集ボタンをクリックしてください。';
$string['downloadaszip'] = 'ダウンロード可能なzip書庫';
$string['downloadtimes'] = 'ダウンロード回数: $a 回';
$string['dwnlnofiles'] = 'アップロードされたファイルはありません。';
$string['dwnlsection'] = 'ダウンロードセクション';
$string['editform1'] = 'フォーマットのことを心配せずに書き込んでください。フォーマットは後から変更することができます。';
$string['editform2'] = '慎重に書き込んでください。全ての編集は記録されます。';
$string['editthispage'] = 'このページを編集する';
$string['emptypage'] = '空のページ';
$string['errorbinandtxt'] = 'フラグエラー: ページタイプはBINまたはTXTです。';
$string['errorhtml'] = 'ページタイプHTML';
$string['errornotype'] = 'フラグエラー: BIN、TXTのどちらでもありません。';
$string['errororreason'] = '備考';
$string['errorroandwr'] = 'フラグエラー: ページに書き込み権と読み取り専用の設定がなされています。';
$string['errorsize'] = 'ページサイズが64Kを超えています';
$string['errversionsave'] = '申し訳ございません、このページを編集している間に他の人が更新したバージョンを保存しました。前のページに戻って、内容をクリップボードにコピーしてください。ページのリロード後、コピーした内容をページに挿入してください。';
$string['ewikiacceptbinary'] = 'バイナリファイルを許可する';
$string['ewikiprinttitle'] = 'wiki名を全てのページに表示する。';
$string['export'] = 'エクスポート';
$string['exportformats'] = 'エクスポートフォーマット';
$string['exportsuccessful'] = 'エクスポートが完了しました。';
$string['exportto'] = 'エクスポート先';
$string['fetchback'] = '取り戻し編集';
$string['file'] = 'ファイル';
$string['filedownload'] = 'ファイルダウンロード';
$string['fileisoftype'] = 'ファイルタイプ';
$string['filtername'] = 'Wikiページ自動リンク';
$string['flagbin'] = 'BIN';
$string['flaghtm'] = 'HTM';
$string['flagoff'] = 'OFF';
$string['flagro'] = 'RO';
$string['flags'] = 'フラグ';
$string['flagsset'] = 'フラグが変更されました。';
$string['flagtxt'] = 'TXT';
$string['flagwr'] = 'WR';
$string['for'] = 'for';
$string['forbidden'] = 'このページにアクセスする権限がありません。';
$string['groups'] = 'グループ';
$string['hits'] = '$a ヒット';
$string['howtooperate'] = '処理内容';
$string['howtowiki'] = 'wikiの使い方';
$string['html'] = 'HTMLフォーマット';
$string['htmlmode'] = 'HTMLモード';
$string['htmlonly'] = 'HTMLのみ';
$string['index'] = 'index';
$string['infoaboutpage'] = '履歴:';
$string['initialcontent'] = '初期ページの選択';
$string['invalidroot'] = '現在のルートページにアクセスする権限が無いため、サイトマップは作成できません。';
$string['lastchanged'] = '最終更新日時: $a';
$string['lastmodified'] = '最終更新日時';
$string['linkdead'] = 'DEAD';
$string['linkok'] = 'OK';
$string['linkschecked'] = 'チェック済みリンク';
$string['listall'] = '全てを表示';
$string['listcandidates'] = '候補一覧';
$string['meta'] = 'メタデータ';
$string['moduledirectory'] = 'モジュールディクショナリ';
$string['modulename'] = 'Wiki';
$string['modulenameplural'] = 'Wiki';
$string['mostoftenchangedpages'] = '最も変更されたページ';
$string['mostvisitedpages'] = '最も閲覧されたページ';
$string['newestpages'] = '最新ページ';
$string['noadministrationaction'] = '管理者権限がありません。';
$string['nocandidatestoremove'] = '削除候補ページがありません、ページ全部を表示するには「 $a 」を選択してください。';
$string['nochangestorevert'] = '前の状態に戻す変更はありません。';
$string['nohtml'] = 'HTML無し';
$string['nolinksfound'] = 'ページにリンクは見つかりませんでした。';
$string['noregexp'] = 'ストリングを訂正してください ( * や regex は使用できません )。最良の方法は攻撃者の「IPアドレスまたはホスト名」を使用することでが、ポート番号を含めないでください  ( 全てのhttpアクセスに関して記述する必要がありますので、設定数を増やすことになります )。';
$string['notadministratewiki'] = 'このwikiの管理を許可されていません!';
$string['nothingtostrip'] = '1つのバージョン以外にページがありません。';
$string['nowikicreated'] = 'このwikiにはエントリがありません。';
$string['of'] = 'of';
$string['offline'] = 'オフライン';
$string['optional'] = 'オプション';
$string['orphanedpage'] = '迷子ページ';
$string['orphanedpages'] = '迷子ページ';
$string['otherwikis'] = '他のWiki';
$string['ownerunknown'] = '不明';
$string['pageactions'] = 'ページアクション';
$string['pageindex'] = 'ページインデックス';
$string['pageinfo'] = 'ページ情報';
$string['pagename'] = 'ページ名';
$string['pagenamechoice'] = '- または -';
$string['pageslinkingto'] = 'このページにリンクしているページ';
$string['pagesremoved'] = 'ページが削除されました。';
$string['pagesreverted'] = '変更が元に戻されました';
$string['pagesstripped'] = 'ページがストリップされました。';
$string['plaintext'] = 'プレインテキスト';
$string['preview'] = 'プレビュー';
$string['readonly'] = '読み取り専用ページ';
$string['refs'] = 'リファレンス';
$string['removenotice'] = 'ここには閲覧されていないページのみが表示されています。ewikiエンジンのチェック機能が限定されているため、閲覧されたページがここに表示される場合もあります。<br />最初にページを空にした場合も、ここに表示されます。同時に他の様々なデータベース診断が行われます。';
$string['removepagecheck'] = '本当にこれらのページを削除してもよろしいですか?';
$string['removepages'] = 'ページの削除';
$string['removeselectedpages'] = '選択したページを削除';
$string['revertallsince'] = 'バージョンを戻す、更新されたページも削除';
$string['revertchanges'] = '変更を元に戻す';
$string['revertlastonly'] = '最新の更新のみ元に戻す';
$string['revertpages'] = '変更の大量取消し';
$string['revertpagescheck'] = '本当に次の変更を元に戻してもよろしいですか:';
$string['revertthe'] = 'バージョンを戻す、影響のあるページだけ削除';
$string['safehtml'] = 'セーフHTML';
$string['save'] = '保存';
$string['searchwiki'] = 'Wikiの検索';
$string['setpageflags'] = 'ページフラグの設定';
$string['sitemap'] = 'サイトマップ';
$string['smfor'] = 'サイトマップ:';
$string['status'] = 'ステータス';
$string['strippagecheck'] = '本当に、これらのページから古いバージョンをストリップしてもよろしいですか:';
$string['strippages'] = 'ページのストリップ';
$string['studentadminoptions'] = '学生管理オプション';
$string['submit'] = '実行';
$string['tabattachments'] = '添付ファイル';
$string['tabedit'] = '編集';
$string['tabinfo'] = '情報';
$string['tablinks'] = 'リンク';
$string['tabview'] = '表示';
$string['thanksforcontribution'] = 'ご協力ありがとうございます。';
$string['thispageisntlinkedfromanywhereelse'] = 'このページはどこからもリンクされていません。';
$string['updatedpages'] = '更新ページ';
$string['updatedwikipages'] = '更新Wikiページ';
$string['uplerror'] = '申し訳ございません、ファイルのアップロード中にエラーが発生しました。';
$string['uplinsect'] = 'アップロード先';
$string['uplnewnam'] = '別名で保存する';
$string['upload0'] = '任意のバイナリファイルをwikiにアップロードする場合は、このフォームを使用してください。';
$string['uploadedon'] = 'アップロード先';
$string['uploadpicturebutton'] = 'アップロード';
$string['uplok'] = 'ファイルが正常にアップロードされました。';
$string['version'] = 'バージョン';
$string['versionrangetoobig'] = '全てのバージョンのページを削除することはできません!最新のバージョンを残してください。';
$string['versions'] = 'バージョン';
$string['versionstodelete'] = '削除するバージョン';
$string['viewpage'] = 'ページの表示';
$string['viewsmfor'] = 'サイトマップを表示';
$string['wantedpages'] = '執筆が望まれているページ';
$string['wikidefaultpagename'] = 'Wikiインデックス';
$string['wikiexport'] = 'ページのエクスポート';
$string['wikiexportcomment'] = 'エクスポートに関する設定を行ってください。';
$string['wikilinkoptions'] = 'Wiki自動リンクオプション';
$string['wikilinks'] = 'Wikiリンク';
$string['wikiname'] = 'ページ名';
$string['wikistartederror'] = '既にエントリが存在します - 変更できません。';
$string['wikitype'] = 'タイプ';
$string['wikiusage'] = 'Wiki使用法';
$string['withbinaries'] = 'バイナリコンテンツを含む';
$string['withvirtualpages'] = 'Wikiリンクを含む';
$string['wrongversionrange'] = '$a は正しい範囲にありません!';

?>
